@@ -419,6 +419,9 @@ class ObjectPresent(_EventData):
 
     """
 
+    STATE_PRESENT = 'PRESENT'
+    STATE_NOT_PRESENT = 'NOT_PRESENT'
+
     def __init__(self,
                  state: str,
                  timestamp: Optional[datetime | str] = None,
@@ -778,6 +781,9 @@ class WaterPresent(_EventData):
 
     """
 
+    STATE_PRESENT = 'PRESENT'
+    STATE_NOT_PRESENT = 'NOT_PRESENT'
+
     def __init__(self,
                  state: str,
                  timestamp: Optional[datetime | str] = None,
@@ -1746,6 +1752,9 @@ class Motion(_EventData):
 
     """
 
+    STATE_MOTION_DETECTED = 'MOTION_DETECTED'
+    STATE_NO_MOTION_DETECTED = 'NO_MOTION_DETECTED'
+
     def __init__(self,
                  state: str,
                  timestamp: Optional[datetime | str] = None,
@@ -1833,6 +1842,9 @@ class DeskOccupancy(_EventData):
 
     """
 
+    STATE_OCCUPIED = 'OCCUPIED'
+    STATE_NOT_OCCUPIED = 'NOT_OCCUPIED'
+
     def __init__(self,
                  state: str,
                  timestamp: Optional[datetime | str] = None,
